@@ -3,58 +3,56 @@
 //
 // Class: Ui
 //
+#include "ui.h"
 
-#include <wx/textdlg.h>
-#include <wx/intl.h>
-#include <wx/utils.h>
-#include <wx/debugrpt.h>
-#include <wx/filename.h>
-#include <wx/app.h>
-#include <wx/log.h>
-#include <wx/stdpaths.h>
-
-#include <stdexcept>
-
-#include <lslutils/globalsmanager.h>
 #include <lslunitsync/springbundle.h>
 #include <lslunitsync/unitsync.h>
+#include <lslutils/globalsmanager.h>
+#include <wx/app.h>
+#include <wx/debugrpt.h>
+#include <wx/filename.h>
+#include <wx/intl.h>
+#include <wx/log.h>
+#include <wx/stdpaths.h>
+#include <wx/textdlg.h>
+#include <wx/utils.h>
+#include <stdexcept>
 
-#include "ui.h"
-#include "offlineserver.h"
-#include "tasserver.h"
-#include "utils/slconfig.h"
-#include "iserver.h"
-#include "serverselector.h"
-#include "spring.h"
 #include "channel.h"
-#include "gui/connectwindow.h"
-#include "gui/mainwindow.h"
-#include "user.h"
-#include "utils/conversion.h"
-#include "utils/uievents.h"
-#include "utils/slpaths.h"
-#include "utils/version.h"
-#include "utils/globalevents.h"
-#include "utils/platform.h"
-#include "gui/uiutils.h"
-#include "gui/chatpanel.h"
+#include "downloader/prdownloader.h"
+#include "exception.h"
+#include "gui/agreementdialog.h"
 #include "gui/battlelist/battlelisttab.h"
+#include "gui/chatpanel.h"
+#include "gui/connectwindow.h"
+#include "gui/customdialogs.h"
 #include "gui/hosting/battleroomtab.h"
 #include "gui/hosting/mainjoinbattletab.h"
 #include "gui/hosting/mainsingleplayertab.h"
 #include "gui/mainchattab.h"
 #include "gui/maindownloadtab.h"
-#include "downloader/prdownloader.h"
-#include "gui/agreementdialog.h"
-#include "updatehelper.h"
-#include "gui/customdialogs.h"
+#include "gui/mainwindow.h"
 #include "gui/textentrydialog.h"
-#include "log.h"
-#include "settings.h"
-#include "servermanager.h"
-#include "exception.h"
+#include "gui/uiutils.h"
 #include "ibattle.h"
-
+#include "iserver.h"
+#include "log.h"
+#include "offlineserver.h"
+#include "servermanager.h"
+#include "serverselector.h"
+#include "settings.h"
+#include "spring.h"
+#include "tasserver.h"
+#include "updatehelper.h"
+#include "user.h"
+#include "utils/conversion.h"
+#include "utils/globalevents.h"
+#include "utils/platform.h"
+#include "utils/slconfig.h"
+#include "utils/slpaths.h"
+#include "utils/sortutil.h"
+#include "utils/uievents.h"
+#include "utils/version.h"
 #ifndef DISABLE_SOUND
 #include "sound/alsound.h"
 #endif
@@ -633,6 +631,7 @@ void Ui::OnSaidBattle(IBattle& /*battle*/, const wxString& nick, const wxString&
 void Ui::OnSpringTerminated(wxCommandEvent& data)
 {
 	const int exit_code = data.GetInt();
+	wxLogInfo("Exiting with %d", exit_code);
 
 	if (!m_serv)
 		return;
@@ -647,9 +646,8 @@ void Ui::OnSpringTerminated(wxCommandEvent& data)
 			battle->SetIsLocked(false);
 			battle->SendHostInfo(IBattle::HI_Locked);
 		}
-	} catch (assert_exception) {
+	} catch (assert_exception&) {
 	}
-	wxLogInfo("Exiting with %d", exit_code);
 }
 
 
@@ -782,9 +780,9 @@ void Ui::OnLobbyDownloaded(wxCommandEvent& data)
 
 void Ui::CheckForUpdates(bool is_interactive)
 {
-	std::string latestversion = GetLatestVersion(is_interactive);
+	std::string latestVersion = GetLatestVersion(!is_interactive);
 
-	if (latestversion.empty()) {
+	if (latestVersion.empty()) {
 		if (is_interactive) {
 			customMessageBoxModal(SL_MAIN_ICON, _(
 			  "There was an error checking for the latest version.\n"
@@ -797,43 +795,53 @@ void Ui::CheckForUpdates(bool is_interactive)
 	//get current rev w/o AUX_VERSION added
 	const std::string myVersion = GetSpringlobbyVersion();
 
-	const wxString msg = _("Your Version: ") + myVersion + _T("\n") + _("Latest Version: ") + latestversion;
-	if (latestversion == myVersion) {
+	const wxString versionMessage = _("Your Version: ") + myVersion + '\n' + _("Latest Version: ") + latestVersion;
+	int isMyVersionOld = CompareVersionStrings(myVersion, latestVersion);
+
+	if (0 == isMyVersionOld) {
 		if (is_interactive) {
 			customMessageBoxModal(SL_MAIN_ICON, wxString::Format(
 			  _("Your %s version is up to date."), GetSpringlobbyName())
-			  + _T("\n\n") + msg, _("Up to Date"));
+			  + _T("\n\n") + versionMessage, _("Up to Date"));
 		}
-		return;
-	}
+	} else if (isMyVersionOld > 0) {
+		wxString message;
+		message += wxString::Format(_("Your %s version is not up to date."), GetSpringlobbyName());
+		message += wxString::Format(_T("\n\n%s\n\n"), versionMessage);
+
 #ifdef __WXMSW__
-	const wxString message = wxString::Format(_("Your %s version is not up to date.") + _T("\n\n%s\n\n") + _("Would you like to update to the new version?"),
-						  TowxString(GetSpringlobbyName()).c_str(),
-						  msg.c_str());
-	const wxString heading = wxString::Format(_("Update %s?"), GetSpringlobbyName());
-	if (!Ask(heading, message))
-		return;
-	try {
-		prDownloader().UpdateApplication(GetDownloadUrl(latestversion));
-	} catch (Exception& ex) {
-		//this will also happen if updater exe is not present so we don't really ne special check for existance of it
-		const wxString errormsg = wxString::Format(_("Automatic update failed.") +_T("\n%s\n%s\n") +
-					_("you will be redirected to a web page with instructions and the download link will be opened in your browser."),
-							   ex.Reason(), msg);
-		customMessageBox(SL_MAIN_ICON, errormsg, _("Updater error."));
-		OpenWebBrowser(_T("https://github.com/springlobby/springlobby/wiki/Install#Windows_Binary"));
-		OpenWebBrowser(TowxString(GetDownloadUrl(latestversion)));
-		return;
-	} catch (...) {
-		wxLogError("Unknown exception");
-	}
+		message += _("Would you like to update to the new version?");
+
+		const wxString heading = wxString::Format(_("Update %s?"), GetSpringlobbyName());
+		if (!Ask(heading, message))
+			return;
+		try {
+			prDownloader().UpdateApplication(GetDownloadUrl(latestVersion));
+		} catch (Exception& ex) {
+			//this will also happen if updater exe is not present so we don't really ne special check for existance of it
+			wxString errorMsg = _("Automatic update failed.") + '\n';
+			errorMsg += ex.Reason() + '\n';
+			errorMsg += versionMessage + '\n';
+			errorMsg += _("The instructions for updating manually have been opened in your web browser.");
+			customMessageBox(SL_MAIN_ICON, errorMsg, _("Updater error."));
+			OpenWebBrowser(_T("https://github.com/springlobby/springlobby/wiki/Install#Windows_Binary"));
+			OpenWebBrowser(TowxString(GetDownloadUrl(latestVersion)));
+		} catch (...) {
+			wxLogError("Unknown exception");
+		}
 #else
-	const wxString motivation = _("Please update to the latest version before reporting bugs.");
-	const wxString doublenl = _T("\n\n");
-	customMessageBoxModal(SL_MAIN_ICON,
-	  wxString::Format(_("Your %s version is not up to date."), GetSpringlobbyName())
-	  + doublenl + msg + doublenl + motivation, _("Not up to Date"));
+		message += _("Please update to the latest version before reporting bugs.");
+		customMessageBoxModal(SL_MAIN_ICON, message, _("Not up to Date"));
 #endif
+	} else {
+		if (is_interactive) {
+			wxString message;
+			message += wxString::Format(_("Your %s version is newer than the latest release."), GetSpringlobbyName());
+			message += wxString::Format(_T("\n\n%s\n\n"), versionMessage);
+			message += _("Thank you for helping with testing!");
+			customMessageBoxModal(SL_MAIN_ICON, message, _T("Much development, wow"));
+		}
+	}
 }
 
 
@@ -949,7 +957,9 @@ void Ui::OnInvalidFingerprintReceived(const std::string& fingerprint, const std:
 	if (expected_fingerprint.empty()) {
 		answer = customMessageBox(SL_MAIN_ICON, _("The certificate by the server is unkown. Do you want to trust it? Please verify the fingerprint:\n") + TowxString(fingerprint)  , _("Unknown Certificate"), wxYES_NO | wxCANCEL);
 	} else {
-		answer = customMessageBox(SL_MAIN_ICON, _("The certificate by the server is invalid! Maybe there is a MITM ongoing. Do you want ignore this warning?:\n") + TowxString(fingerprint)  , _("Unknown Certificate"), wxYES_NO | wxCANCEL);
+		answer = customMessageBox(SL_MAIN_ICON,
+		  wxString::Format(_("The server provided an invalid certificate! Maybe there is a MITM attack ongoing. Do you want ignore this warning?\nExpected:\n%s\nReceived:\n%s"),
+		  expected_fingerprint, fingerprint), _("Unknown Certificate"), wxYES_NO | wxCANCEL);
 	}
 	if (answer != wxYES) {
 		return;
