@@ -6,31 +6,29 @@
 
 #include "settings.h"
 
-#include "utils/wxTranslationHelper.h"
-#include "utils/slconfig.h"
-
-#include <wx/filename.h>
-#include <wx/filefn.h>
-#include <wx/intl.h>
-#include <wx/stdpaths.h>
-#include <wx/filename.h>
-#include <wx/colour.h>
-#include <wx/cmndata.h>
-#include <wx/font.h>
-#include <wx/log.h>
-#include <wx/wfstream.h>
-#include <wx/settings.h>
-#include <wx/tokenzr.h>
-#include <wx/colourdata.h>
-#include <set>
-#include <cstdlib>
 #include <lslutils/globalsmanager.h>
+#include <wx/cmndata.h>
+#include <wx/colour.h>
+#include <wx/colourdata.h>
+#include <wx/filefn.h>
+#include <wx/filename.h>
+#include <wx/font.h>
+#include <wx/intl.h>
+#include <wx/log.h>
+#include <wx/settings.h>
+#include <wx/stdpaths.h>
+#include <wx/tokenzr.h>
+#include <wx/wfstream.h>
+#include <cstdlib>
+#include <set>
 
-#include "utils/conversion.h"
-#include "utils/platform.h"
-#include "utils/slpaths.h"
 #include "playbackfiltervalues.h"
 #include "springsettings/presets.h"
+#include "utils/conversion.h"
+#include "utils/platform.h"
+#include "utils/slconfig.h"
+#include "utils/slpaths.h"
+#include "utils/wxTranslationHelper.h"
 
 const wxChar sep = wxFileName::GetPathSeparator();
 const wxString sepstring = wxString(sep);
@@ -1116,7 +1114,7 @@ void Settings::SetColumnWidth(const wxString& list_name, const int column_ind, c
 	cfg().Write(_T( "GUI/ColumnWidths/" ) + list_name + _T( "/" ) + TowxString(column_ind), column_width);
 }
 
-void Settings::SetColumnVisibility(const wxString& list_name, const int column_ind, const bool columnIsHidden)
+void Settings::SetColumnHidden(const wxString& list_name, const int column_ind, const bool columnIsHidden)
 {
 	cfg().Write(_T( "GUI/ColumnVisibilities/" ) + list_name + _T( "/" ) + TowxString(column_ind), columnIsHidden);
 }
@@ -1130,12 +1128,11 @@ int Settings::GetColumnWidth(const wxString& list_name, const int column)
 	return width;
 }
 
-bool Settings::GetColumnVisibility(const wxString& list_name, const int column)
+bool Settings::IsColumnHidden(const wxString& list_name, const int column, bool defVal)
 {
 	bool isHidden;
-
-	cfg().Read(_T( "/GUI/ColumnVisibilities/" ) + list_name + _T( "/" ) + TowxString(column), &isHidden, false);
-
+	cfg().Read(wxString::Format(_T("/GUI/ColumnVisibilities/%s/%d"), list_name, column),
+	           &isHidden, defVal);
 	return isHidden;
 }
 
