@@ -9,35 +9,32 @@ lsl/networking/tasserver.cpp
 
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 **/
-
-
-#include <wx/string.h>
-#include <wx/intl.h>
-#include <wx/protocol/http.h>
-#include <wx/socket.h>
-#include <wx/log.h>
-#include <wx/timer.h>
-
-#include <stdexcept>
-#include <algorithm>
-#include <map>
-
 #include "tasserver.h"
-#include "serverevents.h"
-#include "socket.h"
-#include "log.h"
-#include "settings.h"
-#include "utils/base64.h"
-#include "utils/md5.h"
-#include "utils/tasutil.h"
-#include "utils/conversion.h"
-#include "utils/slconfig.h"
-#include "utils/version.h"
 
 #include <json/reader.h>
 #include <lslutils/misc.h>
+#include <wx/intl.h>
+#include <wx/log.h>
+#include <wx/protocol/http.h>
+#include <wx/socket.h>
+#include <wx/string.h>
+#include <wx/timer.h>
+#include <algorithm>
+#include <map>
+#include <stdexcept>
 
-SLCONFIG("/Server/ExitMessage", "Using http://springlobby.info/", "Message which is send when leaving server");
+#include "log.h"
+#include "serverevents.h"
+#include "settings.h"
+#include "socket.h"
+#include "utils/base64.h"
+#include "utils/conversion.h"
+#include "utils/md5.h"
+#include "utils/slconfig.h"
+#include "utils/tasutil.h"
+#include "utils/version.h"
+
+SLCONFIG("/Server/ExitMessage", "Using https://springlobby.info/", "Message which is send when leaving server");
 
 // times in milliseconds
 #define PING_TIME 30000
@@ -555,7 +552,8 @@ void TASServer::ExecuteCommand(const std::string& cmd, const std::string& inpara
 #endif
 	} else if (cmd == "OK") {
 		if (!m_sock->IsTLS()) {
-			m_sock->StartTLS(sett().GetServerFingerprint(GetServerName()));
+			wxLogInfo("%s:%d %s", m_serverinfo.hostname.c_str(), m_serverinfo.port, m_serverinfo.fingerprint.c_str());
+			m_sock->StartTLS(m_serverinfo.fingerprint);
 			Start(); //restart ping as server + client have startet TLS
 		}
 	} else if (cmd == "ACCEPTED") {
@@ -1311,35 +1309,40 @@ void TASServer::JoinBattle(const int& battleid, const std::string& password)
 	m_finalize_join_battle_pw = password;
 	m_finalize_join_battle_id = battleid;
 
-	if (BattleExists(battleid)) {
-		IBattle* battle = &GetBattle(battleid);
+	if (!BattleExists(battleid)) {
+		wxLogMessage(_T("battle doesn't exist"));
+		return;
+	}
+	IBattle* battle = &GetBattle(battleid);
 
-		if (battle) {
-			if ((battle->GetNatType() == NAT_Hole_punching) || (battle->GetNatType() == NAT_Fixed_source_ports)) {
-				m_udp_private_port = sett().GetClientPort();
+	if (battle == nullptr) {
+		wxLogMessage(_T("battle doesnt exist (null)"));
+		return;
+	}
 
-				m_last_udp_ping = 0;
-				// its important to set time now, to prevent Update()
-				// from calling FinalizeJoinBattle() on timeout.
-				// m_do_finalize_join_battle must be set to true after setting time, not before.
-				m_do_finalize_join_battle = true;
-				for (int n = 0; n < 5; ++n) { // do 5 udp pings with tiny interval
-					UdpPingTheServer(GetUserName());
-					// sleep(0);// sleep until end of timeslice.
-				}
-				m_last_udp_ping = 0; // set time again
-			} else {
-				// if not using nat, finalize now.
-				m_do_finalize_join_battle = true;
-				FinalizeJoinBattle();
-			}
-		} else {
-			wxLogMessage(_T("battle doesnt exist (null)"));
+	if ((battle->GetEngineName() == "spring") && (battle->GetEngineVersion() == "98.0")) {
+		wxLogError("Spring 98.0 is broken, refusing to join battle");
+		return;
+	}
+
+	if ((battle->GetNatType() == NAT_Hole_punching) || (battle->GetNatType() == NAT_Fixed_source_ports)) {
+		m_udp_private_port = sett().GetClientPort();
+
+		m_last_udp_ping = 0;
+		// its important to set time now, to prevent Update()
+		// from calling FinalizeJoinBattle() on timeout.
+		// m_do_finalize_join_battle must be set to true after setting time, not before.
+		m_do_finalize_join_battle = true;
+		for (int n = 0; n < 5; ++n) { // do 5 udp pings with tiny interval
+			UdpPingTheServer(GetUserName());
+			// sleep(0);// sleep until end of timeslice.
 		}
+		m_last_udp_ping = 0; // set time again
 	} else {
-		wxLogMessage(_T("battle doesnt exist"));
+		// if not using nat, finalize now.
+		m_do_finalize_join_battle = true;
+		FinalizeJoinBattle();
 	}
-	//SendCmd( _T("JOINBATTLE"), wxString::Format( _T("%d"), battleid ) + std::string(" ") + password );
 }
 
 
@@ -1448,7 +1451,7 @@ void TASServer::SendHostInfo(HostInfo update)
 		}
 	}
 	if ((update & IBattle::HI_Restrictions) > 0) {
-		std::map<std::string, int> units = battle.RestrictedUnits();
+		const std::map<std::string, int>& units = battle.GetRestrictedUnits();
 		SendCmd("ENABLEALLUNITS", "", battle.IsProxy());
 		if (!units.empty()) {
 			std::string msg;
